#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author:    thepoy
# @Email:     thepoy@163.com
# @File Name: types.py
# @Created:   2023-02-07 13:08:55
# @Modified:  2023-02-07 13:09:22

from os import PathLike

StrPath = str | PathLike[str]
